`timescale 1ns / 1ps
//////////////////////////////////////////////////////////////////////////////////
// Company: 
// Engineer: 
// 
// Create Date: 2020/04/05 16:07:02
// Design Name: 
// Module Name: SSD_driver
// Project Name: 
// Target Devices: 
// Tool Versions: 
// Description: 
// 
// Dependencies: 
// 
// Revision:
// Revision 0.01 - File Created
// Additional Comments:
// 
//////////////////////////////////////////////////////////////////////////////////


module SSD_driver(                               // control common-anode and individual-cathode of seven-segment display
    output reg [7:0]  cathode,                   // cathodes of similar segments on all four displays
    output reg [3:0]  anode,                     // anodes of the seven LEDs forming each digit
    input      [31:0] content,                   // SSD pattern to display
    input             clk_100MHz,                // 100M Hz global clock
    input             rst_n                      // active low reset
    );
    reg [20:0] q_counter;                        // frequency divider
    
    // frequency divider
    always @ (posedge clk_100MHz or negedge rst_n)
    begin
        if (~rst_n)
            q_counter <= 0;                      // active low reset
        else
            q_counter <= q_counter + 1;          // add 1
    end
    
    // anode enable
    always @ (q_counter[20:19])                  // take a suitable refresh frequency
    begin
        case (q_counter[20:19])
            2'b00:   anode <= 4'b1110;           // 1st digit
            2'b01:   anode <= 4'b1101;           // 2nd digit
            2'b10:   anode <= 4'b1011;           // 3rd digit
            2'b11:   anode <= 4'b0111;           // 4th digit
            default: anode <= 4'b0000;           // all digit
        endcase
    end
    
    // cathode selection
    always @ (q_counter[20:19])                  // take a suitable refresh frequency
    begin
        case (q_counter[20:19])
            2'b00:   cathode <= content[ 7: 0];  // 1st digit
            2'b01:   cathode <= content[15: 8];  // 2nd digit
            2'b10:   cathode <= content[23:16];  // 3rd digit
            2'b11:   cathode <= content[31:24];  // 4th digit
            default: cathode <= 8'b0000000_0;    // all on
        endcase
    end
    
endmodule                                        // SSD_driver
